#!/usr/bin/env python
""" mbb_mqc_plugin functions

We can add any custom Python functions here and call them
using the setuptools plugin hooks.
"""

from __future__ import print_function
from pkg_resources import get_distribution
import logging

from multiqc.utils import report, util_functions, config

# Initialise the main MultiQC logger
log = logging.getLogger('multiqc')

# Save this plugin's version number (defined in setup.py) to the MultiQC config
config.mbb_mqc_plugin_version = get_distribution("mbb_mqc_plugin").version


# Add default config options for the things that are used in MultiQC_NGI
def mbb_mqc_plugin_execution_start():
    """ Code to execute after the config files and
    command line flags have been parsedself.

    This setuptools hook is the earliest that will be able
    to use custom command line flags.
    """

    # Halt execution if we've disabled the plugin
    if config.kwargs.get('disable_plugin', True):
        return None

    log.info("Running mbb_mqc_plugin Plugin v{}".format(config.mbb_mqc_plugin_version))

    # Add to the main MultiQC config object.
    # User config files have already been loaded at this point
    #   so we check whether the value is already set. This is to avoid
    #   clobbering values that have been customised by users.

    if 'blast/blast_data' not in config.sp:
        config.update_dict( config.sp, { 'blast/blast_data': { 'fn': 'blastout*.tsv' } } )
    if 'krona_iframe/krona_data' not in config.sp:
        config.update_dict( config.sp, { 'krona_iframe/krona_data': { 'fn': 'text.krona.tsv' } } )
    if 'deepvariant_iframe/deepvariant_data' not in config.sp:
        config.update_dict( config.sp, { 'deepvariant_iframe/deepvariant_data': { 'fn': 'text.deepvariant.tsv' } } )
    if 'plot_vcf_dv_iframes/plot_vcf_dv_iframes_data' not in config.sp:
        config.update_dict( config.sp, { 'plot_vcf_dv_iframes/plot_vcf_dv_iframes_data': { 'fn': 'vcf_plots_mqc_list.tsv' } } )
    if 'generic_iframe/generic_data' not in config.sp:
        config.update_dict( config.sp, { 'generic_iframe/generic_data': { 'fn': 'text.generic.tsv' } } )
    

    # Some additional filename cleaning
    config.fn_clean_exts.extend([
        '.my_tool_extension',
        '.removeMetoo'
    ])

    # Ignore some files generated by the custom pipeline
    config.fn_ignore_paths.extend([
        '*/my_awesome_pipeline/fake_news/*',
        '*/my_awesome_pipeline/red_herrings/*',
        '*/my_awesome_pipeline/noisy_data/*',
        '*/my_awesome_pipeline/rubbish/*'
    ])
